@@ -275,6 +275,7 @@ process_count_n <- function(x) {
       # Group by variables including target variables and count them
       group_by(!!treat_var, !!!by, !!!target_var, !!!cols) %>%
       tally(name = "n") %>%
+      mutate(n = as.double(n)) %>%
       ungroup()
 
     # If there is a missing_count_string, but its not in the dataset
@@ -808,7 +809,7 @@ process_count_denoms <- function(x) {
       # For distinct counts, we want to defer back to the
       # population dataset. Trigger this by identifying that
       # the population dataset was overridden
-      if (!isTRUE(all.equal(pop_data, target))) {
+      if (!isTRUE(try(identical(pop_data, target)))) {
         if(deparse(denom_where) != deparse(where)){
           warning(paste0("A `denom_where` has been set with a pop_data. The `denom_where` has been ignored.",
           "You should use `set_pop_where` instead of `set_denom_where`.", sep = "\n"),
